@@ -10,26 +10,39 @@ from cookiecutter.environment import StrictEnvironment
 from cookiecutter.exceptions import UndefinedVariableInTemplate
 
 
-def read_user_variable(var_name, default_value):
+def read_user_variable(var_name, default_value, prompts=None):
     """Prompt user for variable and return the entered value or given default.
 
     :param str var_name: Variable of the context to query the user
     :param default_value: Value that will be returned if no input happens
     """
-    # Please see https://click.palletsprojects.com/en/7.x/api/#click.prompt
-    return click.prompt(var_name, default=default_value)
+    question = (
+        prompts[var_name]
+        if prompts and var_name in prompts.keys() and prompts[var_name]
+        else var_name
+    )
+    return click.prompt(question, default=default_value)
 
 
-def read_user_yes_no(question, default_value):
+def read_user_yes_no(var_name, default_value, prompts=None):
     """Prompt the user to reply with 'yes' or 'no' (or equivalent values).
 
-    Note:
-      Possible choices are 'true', '1', 'yes', 'y' or 'false', '0', 'no', 'n'
+    - These input values will be converted to ``True``:
+      "1", "true", "t", "yes", "y", "on"
+    - These input values will be converted to ``False``:
+      "0", "false", "f", "no", "n", "off"
+
+    Actual parsing done by :func:`click.prompt`; Check this function codebase change in
+    case of unexpected behaviour.
 
     :param str question: Question to the user
     :param default_value: Value that will be returned if no input happens
     """
-    # Please see https://click.palletsprojects.com/en/7.x/api/#click.prompt
+    question = (
+        prompts[var_name]
+        if prompts and var_name in prompts.keys() and prompts[var_name]
+        else var_name
+    )
     return click.prompt(question, default=default_value, type=click.BOOL)
 
 
@@ -38,11 +51,10 @@ def read_repo_password(question):
 
     :param str question: Question to the user
     """
-    # Please see https://click.palletsprojects.com/en/7.x/api/#click.prompt
     return click.prompt(question, hide_input=True)
 
 
-def read_user_choice(var_name, options):
+def read_user_choice(var_name, options, prompts=None):
     """Prompt the user to choose from several options for the given variable.
 
     The first item will be returned if no input happens.
@@ -51,7 +63,6 @@ def read_user_choice(var_name, options):
     :param list options: Sequence of options that are available to select from
     :return: Exactly one item of ``options`` that has been chosen by the user
     """
-    # Please see https://click.palletsprojects.com/en/7.x/api/#click.prompt
     if not isinstance(options, list):
         raise TypeError
 
@@ -61,13 +72,28 @@ def read_user_choice(var_name, options):
     choice_map = OrderedDict((f'{i}', value) for i, value in enumerate(options, 1))
     choices = choice_map.keys()
     default = '1'
-
+    question = f"Select {var_name}"
     choice_lines = ['{} - {}'.format(*c) for c in choice_map.items()]
+
+    # Handle if human-readable prompt is provided
+    if prompts and var_name in prompts.keys():
+        if isinstance(prompts[var_name], str):
+            question = prompts[var_name]
+        else:
+            if "__prompt__" in prompts[var_name]:
+                question = prompts[var_name]["__prompt__"]
+            choice_lines = [
+                f"{i} - {prompts[var_name][p]}"
+                if p in prompts[var_name]
+                else f"{i} - {p}"
+                for i, p in choice_map.items()
+            ]
+
     prompt = '\n'.join(
         (
-            f'Select {var_name}:',
-            '\n'.join(choice_lines),
-            'Choose from {}'.format(', '.join(choices)),
+            f"{question}:",
+            "\n".join(choice_lines),
+            f"Choose from {', '.join(choices)}",
         )
     )
 
@@ -91,9 +117,9 @@ def process_json(user_value, default_value=None):
 
     try:
         user_dict = json.loads(user_value, object_pairs_hook=OrderedDict)
-    except Exception:
+    except Exception as error:
         # Leave it up to click to ask the user again
-        raise click.UsageError('Unable to decode to JSON.')
+        raise click.UsageError('Unable to decode to JSON.') from error
 
     if not isinstance(user_dict, dict):
         # Leave it up to click to ask the user again
@@ -102,19 +128,23 @@ def process_json(user_value, default_value=None):
     return user_dict
 
 
-def read_user_dict(var_name, default_value):
+def read_user_dict(var_name, default_value, prompts=None):
     """Prompt the user to provide a dictionary of data.
 
     :param str var_name: Variable as specified in the context
     :param default_value: Value that will be returned if no input is provided
     :return: A Python dictionary to use in the context.
     """
-    # Please see https://click.palletsprojects.com/en/7.x/api/#click.prompt
     if not isinstance(default_value, dict):
         raise TypeError
 
+    question = (
+        prompts[var_name]
+        if prompts and var_name in prompts.keys() and prompts[var_name]
+        else var_name
+    )
     user_value = click.prompt(
-        var_name,
+        question,
         default=DEFAULT_DISPLAY,
         type=click.STRING,
         value_proc=functools.partial(process_json, default_value=default_value),
@@ -143,8 +173,8 @@ def render_variable(env, raw, cookiecutter_dict):
         being populated with variables.
     :return: The rendered value for the default variable.
     """
-    if raw is None:
-        return None
+    if raw is None or isinstance(raw, bool):
+        return raw
     elif isinstance(raw, dict):
         return {
             render_variable(env, k, cookiecutter_dict): render_variable(
@@ -159,31 +189,36 @@ def render_variable(env, raw, cookiecutter_dict):
 
     template = env.from_string(raw)
 
-    rendered_template = template.render(cookiecutter=cookiecutter_dict)
-    return rendered_template
+    return template.render(cookiecutter=cookiecutter_dict)
 
 
-def prompt_choice_for_config(cookiecutter_dict, env, key, options, no_input):
+def prompt_choice_for_config(
+    cookiecutter_dict, env, key, options, no_input, prompts=None
+):
     """Prompt user with a set of options to choose from.
 
-    Each of the possible choices is rendered beforehand.
+    :param no_input: Do not prompt for user input and return the first available option.
     """
     rendered_options = [render_variable(env, raw, cookiecutter_dict) for raw in options]
-
     if no_input:
         return rendered_options[0]
-    return read_user_choice(key, rendered_options)
+    return read_user_choice(key, rendered_options, prompts)
 
 
 def prompt_for_config(context, no_input=False):
     """Prompt user to enter a new config.
 
     :param dict context: Source for field names and sample values.
-    :param no_input: Prompt the user at command line for manual configuration?
+    :param no_input: Do not prompt for user input and use only values from context.
     """
     cookiecutter_dict = OrderedDict([])
     env = StrictEnvironment(context=context)
 
+    prompts = {}
+    if '__prompts__' in context['cookiecutter'].keys():
+        prompts = context['cookiecutter']['__prompts__']
+        del context['cookiecutter']['__prompts__']
+
     # First pass: Handle simple and raw variables, plus choices.
     # These must be done first because the dictionaries keys and
     # values might refer to them.
@@ -199,24 +234,32 @@ def prompt_for_config(context, no_input=False):
             if isinstance(raw, list):
                 # We are dealing with a choice variable
                 val = prompt_choice_for_config(
-                    cookiecutter_dict, env, key, raw, no_input
+                    cookiecutter_dict, env, key, raw, no_input, prompts
                 )
                 cookiecutter_dict[key] = val
+            elif isinstance(raw, bool):
+                # We are dealing with a boolean variable
+                if no_input:
+                    cookiecutter_dict[key] = render_variable(
+                        env, raw, cookiecutter_dict
+                    )
+                else:
+                    cookiecutter_dict[key] = read_user_yes_no(key, raw, prompts)
             elif not isinstance(raw, dict):
                 # We are dealing with a regular variable
                 val = render_variable(env, raw, cookiecutter_dict)
 
                 if not no_input:
-                    val = read_user_variable(key, val)
+                    val = read_user_variable(key, val, prompts)
 
                 cookiecutter_dict[key] = val
         except UndefinedError as err:
             msg = f"Unable to render variable '{key}'"
-            raise UndefinedVariableInTemplate(msg, err, context)
+            raise UndefinedVariableInTemplate(msg, err, context) from err
 
     # Second pass; handle the dictionaries.
     for key, raw in context['cookiecutter'].items():
-        # Skip private type dicts not ot be rendered.
+        # Skip private type dicts not to be rendered.
         if key.startswith('_') and not key.startswith('__'):
             continue
 
@@ -226,11 +269,11 @@ def prompt_for_config(context, no_input=False):
                 val = render_variable(env, raw, cookiecutter_dict)
 
                 if not no_input and not key.startswith('__'):
-                    val = read_user_dict(key, val)
+                    val = read_user_dict(key, val, prompts)
 
                 cookiecutter_dict[key] = val
         except UndefinedError as err:
             msg = f"Unable to render variable '{key}'"
-            raise UndefinedVariableInTemplate(msg, err, context)
+            raise UndefinedVariableInTemplate(msg, err, context) from err
 
     return cookiecutter_dict
